LuaAuxLib class abstract

Implementers

Constructors

LuaAuxLib()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

argCheck(bool? cond, int arg, String extraMsg) → void
argError(int arg, String extraMsg) → int
callMeta(int obj, String e) → Future<bool>
checkAny(int arg) → void
checkInteger(int arg) → Future<int?>
checkNumber(int arg) → double?
checkStack2(int sz, String msg) → void
checkString(int arg) → String?
checkType(int arg, LuaType t) → void
doFile(String filename) → Future<bool>
doString(String str) → Future<bool>
error2(String fmt, [List<Object?>? a]) → int
getMetafield(int obj, String e) → Future<LuaType>
getMetatableAux(String tname) → Future<LuaType>
getSubTable(int idx, String fname) → Future<bool>
len2(int idx) → Future<int?>
loadFile(String? filename) → ThreadStatus
loadFileX(String? filename, String? mode) → ThreadStatus
loadString(String s) → ThreadStatus
newLib(Map<String, DartFunctionAsync?> l) → Future<void>
newLibTable(Map<String, DartFunction> l) → void
newMetatable(String tname) → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openLibs() → Future<void>
optInteger(int arg, int? d) → Future<int?>
optNumber(int arg, double d) → double?
optString(int arg, String d) → String?
ref(int t) → Future<int>
requireF(String modname, DartFunctionAsync openf, bool glb) → Future<void>
setFuncs(Map<String, DartFunction?> l, int nup) → Future<void>
setFuncsAsync(Map<String, DartFunctionAsync?> l, int nup) → Future<void>
setMetatableAux(String tname) → Future<void>
toString() → String
A string representation of this object.
inherited
toString2(int idx) → Future<String?>
typeName2(int idx) → String
unRef(int t, int ref) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited